@@ -19,7 +19,6 @@ import pyarrow as pa
 import pyarrow.compute as pc
 import pyarrow.csv as pa_csv
 import pyarrow.parquet as pq
-from bs4 import BeautifulSoup
 from rich import box
 from rich.columns import Columns
 from rich.console import Group
@@ -31,16 +30,6 @@ from rich.text import Text
 from edgar._markdown import text_to_markdown
 from edgar._party import Address
 from edgar.attachments import FilingHomepage, Attachment, Attachments, AttachmentServer
-from edgar.filtering import (
-    filter_by_date,
-    filter_by_form,
-    filter_by_cik,
-    filter_by_exchange,
-    filter_by_ticker,
-    filter_by_accession_number
-)
-from edgar.dates import InvalidDateException
-from edgar.formatting import display_size
 from edgar.core import (log, sec_edgar,
                         listify,
                         cache_except_none,
@@ -57,14 +46,23 @@ from edgar.core import (log, sec_edgar,
                         DataPager,
                         PagingState,
                         parallel_thread_map)
-from edgar.formatting import accession_number_text
+from edgar.dates import InvalidDateException
 from edgar.files.html import Document
 from edgar.files.html_documents import get_clean_html
 from edgar.files.htmltools import html_sections
 from edgar.files.markdown import to_markdown
+from edgar.filtering import (
+    filter_by_date,
+    filter_by_form,
+    filter_by_cik,
+    filter_by_exchange,
+    filter_by_ticker,
+    filter_by_accession_number
+)
+from edgar.formatting import accession_number_text
+from edgar.formatting import display_size
 from edgar.headers import FilingDirectory, IndexHeaders
 from edgar.httprequests import download_file, download_text, download_text_between_tags
-from edgar.httprequests import get_with_retry
 from edgar.reference import describe_form
 from edgar.reference.tickers import Exchange
 from edgar.reference.tickers import find_ticker, find_ticker_safe
@@ -72,7 +70,6 @@ from edgar.richtools import repr_rich, print_rich, rich_to_text, Docs
 from edgar.search import BM25Search, RegexSearch
 from edgar.sgml import FilingSGML, Reports, Statements, FilingHeader
 from edgar.storage import local_filing_path, is_using_local_storage
-from edgar.xmltools import child_text
 from edgar.xbrl import XBRL, XBRLFilingWithNoXbrlData
 
 """ Contain functionality for working with SEC filing indexes and filings
@@ -92,11 +89,7 @@ __all__ = [
     'Attachment',
     'Attachments',
     'FilingHomepage',
-    'CurrentFilings',
     'available_quarters',
-    'get_current_filings',
-    'iter_current_filings_pages',
-    'get_all_current_filings',
     'get_by_accession_number',
     'filing_date_to_year_quarters'
 ]
@@ -279,7 +272,9 @@ def read_fixed_width_index(index_text: str,
     )
 
 
-def read_index_file(index_text: str, form_column: int = FORM_INDEX_FORM_COLUMN) -> pa.Table:
+def read_index_file(index_text: str,
+                    form_column: int = FORM_INDEX_FORM_COLUMN,
+                    filing_date_format:str="%Y-%m-%d") -> pa.Table:
     """
     Read the index text using multiple spaces as delimiter
     """
@@ -310,7 +305,7 @@ def read_index_file(index_text: str, form_column: int = FORM_INDEX_FORM_COLUMN)
     ciks = pa.array([int(row[-3]) for row in rows], type=pa.int32())
 
     # Dates are always second-to-last field
-    dates = pc.strptime(pa.array([row[-2] for row in rows]), '%Y-%m-%d', 'us')
+    dates = pc.strptime(pa.array([row[-2] for row in rows]), filing_date_format, 'us')
     dates = pc.cast(dates, pa.date32())
 
     # Accession numbers are in the file path
@@ -382,12 +377,13 @@ def fetch_daily_filing_index(date: str,
     year, month, day = date.split("-")
     quarter = (int(month) - 1) // 3 + 1
     url = daily_index_url.format(year, quarter, index, date.replace("-", ""))
-    index_table = fetch_filing_index_at_url(url, index)
+    index_table = fetch_filing_index_at_url(url, index, filing_date_format='%Y%m%d')
     return index_table
 
 
 def fetch_filing_index_at_url(url: str,
-                              index: str) -> Optional[pa.Table]:
+                              index: str,
+                              filing_date_format:str='%Y-%m-%d') -> Optional[pa.Table]:
     index_text = download_text(url=url)
     assert index_text is not None
     if index == "xbrl":
@@ -395,7 +391,7 @@ def fetch_filing_index_at_url(url: str,
     else:
         # Read as a fixed width index file
         form_column = FORM_INDEX_FORM_COLUMN if index == "form" else COMPANY_INDEX_FORM_COLUMN
-        index_table: pa.Table = read_index_file(index_text, form_column=form_column)
+        index_table: pa.Table = read_index_file(index_text, form_column=form_column, filing_date_format=filing_date_format)
     return index_table
 
 
@@ -1007,319 +1003,16 @@ def get_filings(year: Optional[Years] = None,
     return Filings(sorted_filing_index)
 
 
-"""
-Get the current filings from the SEC. Use this to get the filings filed after the 5:30 deadline
-"""
-GET_CURRENT_URL = "https://www.sec.gov/cgi-bin/browse-edgar?action=getcurrent&output=atom&owner=only&count=100"
-title_regex = re.compile(r"(.*) - (.*) \((\d+)\) \((.*)\)")
-summary_regex = re.compile(r'<b>([^<]+):</b>\s+([^<\s]+)')
 
 
-def parse_title(title: str):
-    """
-    Given the title in this example
-
-    "144 - monday.com Ltd. (0001845338) (Subject)"
-    which contains the form type, company name, CIK, and status
-    parse into a tuple of form type, company name, CIK, and status using regex
-    """
-    match = title_regex.match(title)
-    assert match, f"Could not parse title: {title} using regex: {title_regex}"
-    return match.groups()
 
 
-def parse_summary(summary: str):
-    """
-    Given the summary in this example
-
-    "Filed: 2021-09-30 AccNo: 0001845338-21-000002 Size: 1 MB"
-
-    parse into a tuple of filing date, accession number, and size
-    """
-    # Remove <b> and </b> tags from summary
-
-    matches = re.findall(summary_regex, summary)
-
-    # Convert matches into a dictionary
-    fields = {k.strip(): (int(v) if v.isdigit() else v) for k, v in matches}
-
-    return datetime.strptime(str(fields.get('Filed', '')), '%Y-%m-%d').date(), fields.get('AccNo')
 
 
-def get_current_url(atom: bool = True,
-                    count: int = 100,
-                    start: int = 0,
-                    form: str = '',
-                    owner: str = 'include'):
-    url = "https://www.sec.gov/cgi-bin/browse-edgar?action=getcurrent"
-
-    count = count if count in [10, 20, 40, 80, 100] else 40
-    owner = owner if owner in ['include', 'exclude', 'only'] else 'include'
-
-    url = url + f"&count={count}&start={start}&type={form}&owner={owner}"
-    if atom:
-        url += "&output=atom"
-    return url
 
 
-@lru_cache(maxsize=32)
-def get_current_entries_on_page(count: int, start: int, form: Optional[str] = None, owner: str = 'include'):
-    url = get_current_url(count=count, start=start, form=form if form else '', owner=owner, atom=True)
-    response = get_with_retry(url)
-
-    soup = BeautifulSoup(response.text, features="xml")
-    entries = []
-    for entry in soup.find_all("entry"):
-        # The title contains the form type, company name, CIK, and status e.g 4 - WILKS LEWIS (0001076463) (Reporting)
-        title = child_text(entry, "title")
-        form_type, company_name, cik, status = parse_title(title)
-        # The summary contains the filing date and link to the filing
-        summary = child_text(entry, "summary")
-        filing_date, accession_number = parse_summary(summary)
-
-        entries.append({'form': form_type,
-                        'company': company_name,
-                        'cik': cik,
-                        'filing_date': filing_date,
-                        'accession_number': accession_number})
-    return entries
 
 
-def get_current_filings(form: str = '',
-                        owner: str = 'include',
-                        page_size: int = 40):
-    """
-    Get the current filings from the SEC
-    :return: The current filings from the SEC
-    """
-    owner = owner if owner in ['include', 'exclude', 'only'] else 'include'
-    page_size = page_size if page_size in [10, 20, 40, 80, 100] else 100
-    start = 0
-
-    entries = get_current_entries_on_page(count=page_size, start=start, form=form, owner=owner)
-    if not entries:
-        return CurrentFilings(filing_index=_empty_filing_index(), owner=owner, form=form, page_size=page_size)
-    return CurrentFilings(filing_index=pa.Table.from_pylist(entries), owner=owner, form=form, page_size=page_size)
-
-
-def iter_current_filings_pages(form: str = '',
-                              owner: str = 'include', 
-                              page_size: int = 100):
-    """
-    Iterator that yields CurrentFilings pages until exhausted.
-    
-    Args:
-        form: Form type to filter by (e.g., "10-K", "8-K")
-        owner: Owner filter ('include', 'exclude', 'only')
-        page_size: Number of filings per page (10, 20, 40, 80, 100)
-    
-    Yields:
-        CurrentFilings: Each page of current filings until no more pages
-        
-    Example:
-        >>> for page in iter_current_filings_pages(form="10-K"):
-        ...     print(f"Processing {len(page)} filings")
-        ...     # Process each page
-    """
-    current_page = get_current_filings(form=form, owner=owner, page_size=page_size)
-    
-    while current_page is not None:
-        yield current_page
-        current_page = current_page.next()
-
-
-def get_all_current_filings(form: str = '', 
-                           owner: str = 'include', 
-                           page_size: int = 100) -> Filings:
-    """
-    Get ALL current filings by iterating through all pages.
-    
-    Args:
-        form: Form type to filter by (e.g., "10-K", "8-K")
-        owner: Owner filter ('include', 'exclude', 'only')
-        page_size: Number of filings per page (10, 20, 40, 80, 100)
-    
-    Returns:
-        Filings: A regular Filings object containing all current filings
-        
-    Example:
-        >>> all_filings = get_all_current_filings(form="10-K")
-        >>> print(f"Found {len(all_filings)} total current 10-K filings")
-    """
-    all_entries = []
-    
-    for page in iter_current_filings_pages(form=form, owner=owner, page_size=page_size):
-        # Convert PyArrow table to list and extend
-        page_entries = page.data.to_pylist()
-        all_entries.extend(page_entries)
-    
-    if not all_entries:
-        return Filings(_empty_filing_index())
-    
-    # Return as regular Filings object (not CurrentFilings)
-    return Filings(pa.Table.from_pylist(all_entries))
-
-
-class CurrentFilings(Filings):
-    """
-    This version of the Filings class is used to get the current filings from the SEC
-    page by page
-    """
-
-    def __init__(self,
-                 filing_index: pa.Table,
-                 form: str = '',
-                 start: int = 1,
-                 page_size: int = 40,
-                 owner: str = 'include'):
-        super().__init__(filing_index, original_state=None)
-        self._start = start
-        self._page_size = page_size
-        self.owner = owner
-        self.form = form
-
-    def next(self):
-        # If the number of entries is less than the page size then we are at the end of the data
-        if len(self.data) < self._page_size:
-            return None
-        start = self._start + len(self.data)
-        next_entries = get_current_entries_on_page(start=start-1, count=self._page_size, form=self.form)
-        if next_entries:
-            # Copy the values to this Filings object and return it
-            self.data = pa.Table.from_pylist(next_entries)
-            self._start = start
-            return self
-
-    def previous(self):
-        # If start = 1 then there are no previous entries
-        if self._start == 1:
-            return None
-        start = max(1, self._start - self._page_size)
-        previous_entries = get_current_entries_on_page(start=start, count=self._page_size, form=self.form)
-        if previous_entries:
-            # Copy the values to this Filings object and return it
-            self.data = pa.Table.from_pylist(previous_entries)
-            self._start = start
-            return self
-
-    def __getitem__(self, item):  # type: ignore
-        item = self.get(item)
-        assert item is not None
-        return item
-
-    def get(self, index_or_accession_number: IntString):
-        if isinstance(index_or_accession_number, int) or index_or_accession_number.isdigit():
-            idx = int(index_or_accession_number)
-            if self._start - 1 <= idx < self._start - 1 + len(self.data):
-                # Where on this page is the index
-                idx_on_page = idx - (self._start - 1)
-                return super().get_filing_at(idx_on_page)
-        else:
-            accession_number = index_or_accession_number.strip()
-            # See if the filing is in this page
-            filing = super().get(accession_number)
-            if filing:
-                return filing
-
-            current_filings = get_current_filings(self.form, self.owner, page_size=100)
-            filing = CurrentFilings._get_current_filing_by_accession_number(current_filings.data, accession_number)
-            if filing:
-                return filing
-            with Status(f"[bold deep_sky_blue1]Searching through the most recent filings for {accession_number}...",
-                        spinner="dots2"):
-                while True:
-                    current_filings = current_filings.next()
-                    if current_filings is None:
-                        return None
-                    filing = CurrentFilings._get_current_filing_by_accession_number(current_filings.data,
-                                                                                    accession_number)
-                    if filing:
-                        return filing
-
-    @staticmethod
-    def _get_current_filing_by_accession_number(data: pa.Table, accession_number: str):
-        mask = pc.equal(data['accession_number'], accession_number)
-        idx = mask.index(True).as_py()
-        if idx > -1:
-            return Filing(
-                cik=data['cik'][idx].as_py(),
-                company=data['company'][idx].as_py(),
-                form=data['form'][idx].as_py(),
-                filing_date=data['filing_date'][idx].as_py(),
-                accession_no=data['accession_number'][idx].as_py(),
-            )
-        return None
-
-    def __rich__(self):
-
-        # Create table with appropriate columns and styling
-        table = Table(
-            show_header=True,
-            header_style="bold",
-            show_edge=True,
-            expand=False,
-            padding=(0, 1),
-            box=box.SIMPLE,
-            row_styles=["", "bold"]
-        )
-
-        # Add columns with specific styling and alignment
-        table.add_column("#", style="dim", justify="right")
-        table.add_column("Form", width=7)
-        table.add_column("CIK", style="dim", width=10, justify="right")
-        table.add_column("Ticker", width=6, style="yellow")
-        table.add_column("Company", style="bold green", width=38, no_wrap=True)
-        table.add_column("Filing Date", width=11)
-        table.add_column("Accession Number", style="dim", width=20)
-
-        # Get current page from data pager
-        current_page = self.data.to_pandas()
-
-        # compute the index from the start and page_size and set it as the index of the page
-        current_page.index = range(self._start - 1, self._start - 1 + len(current_page))
-
-        # Iterate through rows in current page
-        for t in current_page.itertuples():
-            cik = t.cik
-            ticker = find_ticker(cik)
-
-            row = [
-                str(t.Index),
-                t.form,
-                str(cik),
-                ticker,
-                t.company,
-                str(t.filing_date),
-                t.accession_number
-            ]
-            table.add_row(*row)
-
-        # Show paging information only if there are multiple pages
-        elements = [table]
-
-        page_info = Text.assemble(
-            ("Showing ", "dim"),
-            (f"{current_page.index.min():,}", "bold red"),
-            (" to ", "dim"),
-            (f"{current_page.index.max():,}", "bold red"),
-            (" most recent filings.", "dim"),
-            (" Page using ", "dim"),
-            ("← prev()", "bold gray54"),
-            (" and ", "dim"),
-            ("next() →", "bold gray54")
-        )
-
-        elements.extend([Text("\n"), page_info])
-
-        # Get the subtitle
-        start_date, end_date = self.date_range
-        subtitle = "Most recent filings from the SEC"
-        return Panel(
-            Group(*elements),
-            title="SEC Filings",
-            subtitle=subtitle,
-            border_style="bold grey54"
-        )
 
 
 @lru_cache(maxsize=8)
@@ -1514,13 +1207,19 @@ class Filing:
         assert downloaded is not None
         return str(downloaded)
 
-    def markdown(self) -> str:
-        """return the markdown version of this filing html"""
+    def markdown(self, include_page_breaks: bool = False, start_page_number: int = 0) -> str:
+        """
+        Return the markdown version of this filing html
+        
+        Args:
+            include_page_breaks: If True, include page break delimiters in the markdown
+            start_page_number: Starting page number for page break markers (default: 0)
+        """
         html = self.html()
         if html:
             clean_html = get_clean_html(html)
             if clean_html:
-                return to_markdown(clean_html)
+                return to_markdown(clean_html, include_page_breaks=include_page_breaks, start_page_number=start_page_number)
         text_content = self.text()
         return text_to_markdown(text_content)
 
@@ -1942,6 +1641,7 @@ def get_by_accession_number(accession_number: str, show_progress: bool = False):
         filing = get_filing_by_accession(accession_number, year)
 
         if not filing and year == datetime.now().year:
+            from edgar.current_filings import get_current_filings
             filings = get_current_filings()
             filing = filings.get(accession_number)
 
