@@ -243,11 +243,6 @@ def get_identity() -> str:
         os.environ[edgar_identity] = identity
     return identity
 
-
-@lru_cache(maxsize=1)
-def client_headers():
-    return {'User-Agent': get_identity()}
-
 def decode_content(content: bytes):
     try:
         return content.decode('utf-8')
@@ -386,13 +381,6 @@ def filter_by_date(data: pa.Table,
     if isinstance(date, datetime.date) or isinstance(date, datetime.datetime):
         date = date.strftime('%Y-%m-%d')
 
-
-
-
-@lru_cache(maxsize=1)
-def client_headers():
-    return {'User-Agent': get_identity()}
-
 def decode_content(content: bytes):
     try:
         return content.decode('utf-8')
@@ -594,6 +582,9 @@ def has_html_content(content: str) -> bool:
     """
     Check if the content is HTML or inline XBRL HTML
     """
+    if content is None:
+        return False
+        
     if isinstance(content, bytes):
         content = content.decode('utf-8', errors='ignore')
 
@@ -621,6 +612,10 @@ def has_html_content(content: str) -> bool:
                 'xmlns:ix' in first_1000 or
                 'xmlns:html' in first_1000):
             return True
+        
+        # If we have an <html> tag, it's likely HTML content
+        # This catches cases like <html style="..."> that don't have XBRL namespaces
+        return True
 
     # Just check for straightforward HTML
     if first_200_lower.startswith('<html>') and content[-7:].lower().startswith('</html>'):
@@ -677,6 +672,11 @@ def initialize_rich_logging():
 
     # Turn down 3rd party logging
     logging.getLogger("httpx").setLevel(logging.WARNING)
+    logging.getLogger("httpxthrottlecache").setLevel(logging.WARNING)
+    logging.getLogger("pyrate_limiter").setLevel(
+        logging.CRITICAL
+    )  # TODO: Temporary, until next pyrate_limiter update that reduces the spurious "async" message
+
 
 # Turn on rich logging if the environment variable is set
 if os.getenv('EDGAR_USE_RICH_LOGGING', '0') == '1':
