@@ -21,4 +21,9 @@ from edgar.ownership.ownershipforms import (
     PostTransactionAmounts,
     NonDerivativeTransaction,
     NonDerivativeTransactions,
+    TransactionSummary
+)
+
+from edgar.ownership.html_render import (
+    ownership_to_html
 )
